@@ -19,8 +19,6 @@ class Controller(ABC):
         exact_fitness: Callable[[List[float]], List[float]] = None,
         estimator: Estimator = None,
         self_exact: Optional[object] = None,
-        problem_dimensionality: int = -1,
-        solutions=None,
         debug: bool = False,
         **kwargs
     ):
