@@ -6,7 +6,7 @@ from sklearn.neighbors import KDTree, DistanceMetric
 from movado.controller import Controller
 from movado.mab_handler_cats import MabHandlerCATS
 
-
+# TODO make lists global
 class DistanceController(Controller):
     # do not annotate types in __init__, it throws "ABCMeta Object is not subscriptable"
     def __init__(
@@ -14,12 +14,11 @@ class DistanceController(Controller):
         exact_fitness,
         estimator,
         self_exact: Optional[object] = None,
-        problem_dimensionality: int = -1,
-        solutions: List[List[List[float]]] = None,
         nth_nearest=3,
         distance_metric="minkowski",
         threshold="mab",
         debug=False,
+        skip_debug_initialization=False,
         mab_epsilon: float = 0.2,
         mab_bandwidth: int = 1,
         mab_weight: bool = True,
@@ -42,9 +41,22 @@ class DistanceController(Controller):
         self.__distances: List[float] = []
         self.__mab = None
         self.__weight_mab = None
+        self.__params = (
+            "Model_Parameters",
+            {
+                "nth_nearest": self.__nth_nearest,
+                "mab_epsilon": mab_epsilon,
+                "mab_bandwidth": mab_bandwidth,
+                "mab_weight_epsilon": mab_weight_epsilon,
+                "mab_weight_bandwidth": mab_weight_bandwidth,
+            },
+        )
         if self.__threshold == "mab":
             self.__mab = MabHandlerCATS(
-                debug=debug, epsilon=mab_epsilon, bandwidth=mab_bandwidth
+                debug=debug,
+                epsilon=mab_epsilon,
+                bandwidth=mab_bandwidth,
+                controller_params={self.__params[0]: self.__params[1]},
             )
             if mab_weight:
                 self.__weight_mab = MabHandlerCATS(
@@ -52,12 +64,16 @@ class DistanceController(Controller):
                     epsilon=mab_weight_epsilon,
                     bandwidth=mab_weight_bandwidth,
                     debug_path="mab_weight",
+                    controller_params={self.__params[0]: self.__params[1]},
                 )
 
-        if self._debug:
-            Path(self._controller_debug).open("a").write(
-                "Threshold, Nth_Nearest_Distance, Point, Exec_Time, Error, Estimation\n"
-            )
+        if self._debug and not skip_debug_initialization:
+            self.initialize_debug()
+
+    def initialize_debug(self):
+        Path(self._controller_debug).open("a").write(
+            "Model_Parameters, Threshold, Nth_Nearest_Distance, Point, Exec_Time, Error, Estimation\n"
+        )
 
     def compute_objective(self, point: List[int]) -> List[float]:
         out: List[float]
@@ -90,8 +106,9 @@ class DistanceController(Controller):
 
         # TODO probably this check can be done only once
         if self._debug:
-            self._write_debug(
+            self.write_debug(
                 {
+                    self.__params[0]: self.__params[1],
                     "Threshold": 0 if error == 0.0 else threshold,
                     "Nth_Nearest_Distance": 0
                     if not self.__evaluated_points
@@ -106,9 +123,11 @@ class DistanceController(Controller):
             )
         return out
 
-    def _write_debug(self, debug_info: Dict[str, Any]):
+    def write_debug(self, debug_info: Dict[str, Any]):
         Path(self._controller_debug).open("a").write(
-            str(debug_info["Threshold"])
+            str(debug_info["Model_Parameters"])
+            + ", "
+            + str(debug_info["Threshold"])
             + ", "
             + str(debug_info["Nth_Nearest_Distance"])
             + ", "
